@@ -9,7 +9,6 @@
 #define DATA_FRAME_H_
 
 #include <Rdefines.h>
-#include <math.h>
 #include <cstdlib>		// calloc free
 
 class data_frame
@@ -102,7 +101,9 @@ private:
 	void fill_row_names()
 	{
 		unsigned i;
-		char *buf=(char*) calloc(((unsigned) log10(nrow_) + 2), sizeof(char));
+		// Use array of static size for filling
+		// (log10 based calculation resulted in compiler errors on solaris)
+		char *buf=(char*) calloc(((unsigned) 100), sizeof(char));
 	    for(i=0; i < nrow_; ++i)
 	    {
 	    	sprintf(buf,"%i",i + 1);
